==> cloudt-system-api-0.1.2-20230426.065930-1-sources.jar: com/elitescloud/cloudt/system/provider/extend/SysCurrencyRpcService.java <==
package com.elitescloud.cloudt.system.provider.extend;

import com.elitescloud.cloudt.Application;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.system.dto.req.SysCurrencyQueryDTO;
import com.elitescloud.cloudt.system.dto.resp.SysCurrencyRespDTO;
import com.elitesland.cbpl.unicom.annotation.Unicom;
import com.elitesland.cbpl.unicom.domain.InvokeDomain;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Set;

/**
 * 币种服务接口.
 *
 * @author Kaiser（wang shao）
 * @date 3/3/2023
 */
@FeignClient(name = Application.NAME, path = SysCurrencyRpcService.URI)
@Validated
@Unicom(domain = InvokeDomain.SYSTEM)
public interface SysCurrencyRpcService {
    String URI = Application.URI_PREFIX + "/currency";

    /**
     * 根据币种编码获取币种信息
     *
     * @param currCode 币种编码
     * @return 币种信息
     */
    @GetMapping(value = "/getByCode")
    ApiResult<SysCurrencyRespDTO> getByCode(@NotBlank(message = "币种编码为空") @RequestParam(name = "currCode") String currCode);

    /**
     * 根据编码查询币种
     *
     * @param currCodes 币种编码
     * @return 币种信息列表
     */
    @PostMapping(value = "/listByCodes")
    ApiResult<List<SysCurrencyRespDTO>> listByCodes(@RequestBody @NotEmpty(message = "币种编码为空") Set<String> currCodes);

    /**
     * 查询币种
     *
     * @param queryDTO 查询参数
     * @return 币种信息列表
     */
    @PostMapping(value = "/queryList")
    ApiResult<List<SysCurrencyRespDTO>> queryList(@RequestBody SysCurrencyQueryDTO queryDTO);
}

==> cloudt-system-api-0.2.9.1-20240422.034614-1-sources.jar: com/elitescloud/cloudt/system/provider/extend/SysCurrencyRpcService.java <==
package com.elitescloud.cloudt.system.provider.extend;

import com.elitescloud.cloudt.Application;
import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitescloud.cloudt.system.dto.req.SysCurrencyQueryDTO;
import com.elitescloud.cloudt.system.dto.resp.SysCurrencyRespDTO;
import com.elitesland.cbpl.unicom.annotation.Unicom;
import com.elitesland.cbpl.unicom.domain.InvokeDomain;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotEmpty;
import java.util.List;
import java.util.Set;

/**
 * 币种服务接口.
 *
 * @author Kaiser（wang shao）
 * @date 3/3/2023
 */
@Validated
@Unicom(domain = InvokeDomain.SYSTEM, path = SysCurrencyRpcService.URI)
public interface SysCurrencyRpcService {
    String URI = Application.URI_PREFIX + "/currency";

    /**
     * 根据币种编码获取币种信息
     *
     * @param currCode 币种编码
     * @return 币种信息
     */
    @GetMapping(value = "/getByCode")
    ApiResult<SysCurrencyRespDTO> getByCode(@NotBlank(message = "币种编码为空") @RequestParam(name = "currCode") String currCode);

    /**
     * 根据编码查询币种
     *
     * @param currCodes 币种编码
     * @return 币种信息列表
     */
    @PostMapping(value = "/listByCodes")
    ApiResult<List<SysCurrencyRespDTO>> listByCodes(@RequestBody @NotEmpty(message = "币种编码为空") Set<String> currCodes);

    /**
     * 查询币种
     *
     * @param queryDTO 查询参数
     * @return 币种信息列表
     */
    @PostMapping(value = "/queryList")
    ApiResult<List<SysCurrencyRespDTO>> queryList(@RequestBody SysCurrencyQueryDTO queryDTO);
}
